==> v1.16.0.tar.gz: detekt-1.16.0/detekt-rules-naming/src/main/kotlin/io/gitlab/arturbosch/detekt/rules/naming/ClassNaming.kt <==
package io.gitlab.arturbosch.detekt.rules.naming

import io.gitlab.arturbosch.detekt.api.CodeSmell
import io.gitlab.arturbosch.detekt.api.Config
import io.gitlab.arturbosch.detekt.api.Debt
import io.gitlab.arturbosch.detekt.api.Entity
import io.gitlab.arturbosch.detekt.api.Issue
import io.gitlab.arturbosch.detekt.api.LazyRegex
import io.gitlab.arturbosch.detekt.api.Rule
import io.gitlab.arturbosch.detekt.api.Severity
import io.gitlab.arturbosch.detekt.rules.identifierName
import org.jetbrains.kotlin.psi.KtClassOrObject

/**
 * Reports when class or object names which do not follow the specified naming convention are used.
 *
 * @configuration classPattern - naming pattern (default: `'[A-Z][a-zA-Z0-9]*'`)
 * @active since v1.0.0
 */
class ClassNaming(config: Config = Config.empty) : Rule(config) {

    override val defaultRuleIdAliases: Set<String> = setOf("ClassName")

    override val issue = Issue(
        javaClass.simpleName,
        Severity.Style,
        "A class or object's name should fit the naming pattern defined in the projects configuration.",
        debt = Debt.FIVE_MINS
    )

    private val classPattern by LazyRegex(CLASS_PATTERN, "[A-Z][a-zA-Z0-9]*")

    override fun visitClassOrObject(classOrObject: KtClassOrObject) {
        if (!classOrObject.identifierName().matches(classPattern)) {
            report(CodeSmell(
                issue,
                Entity.atName(classOrObject),
                message = "Class and Object names should match the pattern: $classPattern"))
        }
    }

    companion object {
        const val CLASS_PATTERN = "classPattern"
    }
}

==> v1.17.0.tar.gz: detekt-1.17.0/detekt-rules-naming/src/main/kotlin/io/gitlab/arturbosch/detekt/rules/naming/ClassNaming.kt <==
package io.gitlab.arturbosch.detekt.rules.naming

import io.gitlab.arturbosch.detekt.api.CodeSmell
import io.gitlab.arturbosch.detekt.api.Config
import io.gitlab.arturbosch.detekt.api.Debt
import io.gitlab.arturbosch.detekt.api.Entity
import io.gitlab.arturbosch.detekt.api.Issue
import io.gitlab.arturbosch.detekt.api.LazyRegex
import io.gitlab.arturbosch.detekt.api.Rule
import io.gitlab.arturbosch.detekt.api.Severity
import io.gitlab.arturbosch.detekt.api.internal.ActiveByDefault
import io.gitlab.arturbosch.detekt.rules.identifierName
import org.jetbrains.kotlin.psi.KtClassOrObject

/**
 * Reports when class or object names which do not follow the specified naming convention are used.
 *
 * @configuration classPattern - naming pattern (default: `'[A-Z][a-zA-Z0-9]*'`)
 */
@ActiveByDefault(since = "1.0.0")
class ClassNaming(config: Config = Config.empty) : Rule(config) {

    override val defaultRuleIdAliases: Set<String> = setOf("ClassName")

    override val issue = Issue(
        javaClass.simpleName,
        Severity.Style,
        "A class or object's name should fit the naming pattern defined in the projects configuration.",
        debt = Debt.FIVE_MINS
    )

    private val classPattern by LazyRegex(CLASS_PATTERN, "[A-Z][a-zA-Z0-9]*")

    override fun visitClassOrObject(classOrObject: KtClassOrObject) {
        if (!classOrObject.identifierName().matches(classPattern)) {
            report(
                CodeSmell(
                    issue,
                    Entity.atName(classOrObject),
                    message = "Class and Object names should match the pattern: $classPattern"
                )
            )
        }
    }

    companion object {
        const val CLASS_PATTERN = "classPattern"
    }
}
